# Changelog

## 0.1.0 (2026-01-26)


### Features

* add basic logging to discord-llms ([0697b8e](https://github.com/S1M0N38/discord-llms.txt/commit/0697b8ee030092d99ab8f77843c64a41dc23e863))
* add support for channel filtering ([cc31a62](https://github.com/S1M0N38/discord-llms.txt/commit/cc31a621948d1ae6ae285b13fa45cd81810aceb6))
* add support for docker ([875d442](https://github.com/S1M0N38/discord-llms.txt/commit/875d442516743fb6da12fcb5b4b76aecd8d96e77))
* add support for req/res logging ([a0109b6](https://github.com/S1M0N38/discord-llms.txt/commit/a0109b664162321afac88606810039f4aac17af6))
* **bot:** add suppress_embeds=True to suppress embeds in messages ([1ba9ba3](https://github.com/S1M0N38/discord-llms.txt/commit/1ba9ba3a5f7a48cf82b5a6abab0ea3231ce8be12))
* **bot:** make us of discord.py's paginator ([7935340](https://github.com/S1M0N38/discord-llms.txt/commit/7935340ee746f3b778b3ab75b5131d7664c1c67e))
* **config:** make model config more flexible ([91919b8](https://github.com/S1M0N38/discord-llms.txt/commit/91919b8d8d65bb79f422893fb1f3906496054f00))
* implement Discord LLM documentation bot ([01f1cb5](https://github.com/S1M0N38/discord-llms.txt/commit/01f1cb57e81f16a7349324c7dda2beb48c03585e))
* **llm:** move from httpx to openai-python ([6aaf389](https://github.com/S1M0N38/discord-llms.txt/commit/6aaf389ef70a31235966e161d16b793e2dc7dc04))
* **make:** add coverage options to make test ([eeb2ad6](https://github.com/S1M0N38/discord-llms.txt/commit/eeb2ad6a7c97bcbdf92f83b6531de2f5021a59e8))
* **templates:** add response format guidelines ([0b634f5](https://github.com/S1M0N38/discord-llms.txt/commit/0b634f5831ff9d9e54d88457313ca34734143192))
* **templates:** add templates for answering questions and selecting docs ([2c6d696](https://github.com/S1M0N38/discord-llms.txt/commit/2c6d6960ff7c477583d9eedaab17cb689772f938))
* **templates:** add templates for assistant and system ([d491f45](https://github.com/S1M0N38/discord-llms.txt/commit/d491f451d258168711caa8f62de8f44dd49ead14))


### Bug Fixes

* **bot:** handle special characters in language identifiers ([df2e238](https://github.com/S1M0N38/discord-llms.txt/commit/df2e23898171dbda95e2b60d6a9f277958029881))
* **config:** validate url field ([e199efe](https://github.com/S1M0N38/discord-llms.txt/commit/e199efe476f70f400a8e924af4ef88ec2ec11f31))


### Documentation

* **claude:** add CLAUDE.md ([9bb2d43](https://github.com/S1M0N38/discord-llms.txt/commit/9bb2d43540f712b7f48107297266794d159709af))
* **config:** add tips for writing good summaries ([f52e639](https://github.com/S1M0N38/discord-llms.txt/commit/f52e63913de6bf7ab5b78f45dc89cb3a683f39bc))
* **envrc:** remove discord token from .envrc.example ([a742368](https://github.com/S1M0N38/discord-llms.txt/commit/a74236875b9992631e12f474f2195547362b3dbc))
* **envrc:** update example envrc file with project specific commands ([b46bccc](https://github.com/S1M0N38/discord-llms.txt/commit/b46bccc8f9a2ea83a67d29079309e34310dca415))
* improve installation and usage instructions ([f9aa4e5](https://github.com/S1M0N38/discord-llms.txt/commit/f9aa4e5c646475554a6e65773006559e27bfcdfe))
* **readme:** rename docker section to `Deploy (Docker)` ([06b1cef](https://github.com/S1M0N38/discord-llms.txt/commit/06b1cefe51a872ad1cb2388ba075878c5f3348d3))
* **readme:** update usage and config instructions ([f7b8a2d](https://github.com/S1M0N38/discord-llms.txt/commit/f7b8a2d3cfb1389b33fd9b862a80c620cf13455e))
